# V8-CPU Simulator

V8-CPU simulator is used for labs& exercises on first-year(freshman) undergraduate CS course "Fundamental of Computer Science" in Dept. of CS in Tsinghua Univ. This simulator is simulating a simple 8-bit RISC cpu which is based on Appendix C contents in [Computer Science: An Overview](http://www.amazon.com/Computer-Science-Overview-12th-Edition/dp/0133760065) textbook.